4.48. umbra.ui.views — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.48. umbra.ui.views

views.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the Application Views classes.

Others:

## 4.48.1. Module Attributes

`umbra.ui.views.` `LOGGER`

## 4.48.2. Classes

class `umbra.ui.views.` `ReadOnlyFilter`

  Bases: `PyQt4.QtCore.QObject`

  This class is a QObject subclass used as an event filter for the `Abstract_QListView` and `Abstract_QTreeView` classes.

  `eventFilter`(object, event)

    This method reimplements the QObject.eventFilter method.

    Parameters: | object – Object. ( QObject ) event – Event. ( QEvent )
    Returns: | Event filtered. ( Boolean )

class `umbra.ui.views.` `Mixin_AbstractBase`(message=None)

  Bases: `object`

  This class is the base mixin used to bring common capabilities in Application Views classes.

  Parameters: | parent – Object parent. ( QObject ) message – View default message when Model is empty. ( String )

  `message`

    This method is the property for self.__message attribute.

    Returns: | self.__message. ( String )

  `resizeEvent`(event)

    This method reimplements the `*.resizeEvent()` method.

    Parameters: | event – QEvent. ( QEvent )

  `paintEvent`(event)

    This method reimplements the `*.paintEvent()` method.

    Parameters: | event – QEvent. ( QEvent )

class `umbra.ui.views.` `Mixin_AbstractView`(readOnly=None, message=None)

  Bases: `umbra.ui.views.Mixin_AbstractBase`

  This class is a mixin used to bring common capabilities in Application Views classes.

  Parameters: | parent – Object parent. ( QObject ) readOnly – View is read only. ( Boolean ) message – View default message when Model is empty. ( String )

  `readOnly`

    This method is the property for self.__readOnly attribute.

    Returns: | self.__readOnly. ( Boolean )

  `getNodes`()

    This method returns the View nodes.

    Returns: | View nodes. ( List )

  `filterNodes`(pattern, attribute, flags=2)

    This method filters the View Nodes on given attribute using given pattern.

    Parameters: | pattern – Filtering pattern. ( String ) attribute – Filtering attribute. ( String ) flags – Regex filtering flags. ( Integer )
    Returns: | View filtered nodes. ( List )

  `getViewNodesFromIndexes`(*indexes)

    This method returns the View Nodes from given indexes.

    Parameters: | view – View. ( QWidget ) *indexes – Indexes. ( List )
    Returns: | View nodes. ( Dictionary )

  `getViewSelectedNodes`()

    This method returns the View selected nodes.

    Parameters: | view – View. ( QWidget )
    Returns: | View selected nodes. ( Dictionary )

  `getSelectedNodes`()

    This method returns the View selected nodes.

    Returns: | View selected nodes. ( Dictionary )

  `selectViewIndexes`(indexes, flags=<PyQt4.QtGui.SelectionFlags object at 0x106884980>)

    This method selects the View given indexes.

    Parameters: | view – View. ( QWidget ) indexes – Indexes to select. ( List ) flags – Selection flags. ( QItemSelectionModel.SelectionFlags )
    Returns: | Definition success. ( Boolean )

  `selectIndexes`(indexes, flags=<PyQt4.QtGui.SelectionFlags object at 0x106884c90>)

    This method selects given indexes.

    Parameters: | indexes – Indexes to select. ( List ) flags – Selection flags. ( QItemSelectionModel.SelectionFlags )
    Returns: | Method success. ( Boolean )

class `umbra.ui.views.` `Mixin_AbstractWidget`(message=None)

  Bases: `umbra.ui.views.Mixin_AbstractBase`

  This class is a mixin used to bring common capabilities in Application Widgets Views classes.

  Parameters: | parent – Object parent. ( QObject ) message – View default message when Model is empty. ( String )

class `umbra.ui.views.` `Abstract_QListView`(parent=None, readOnly=False, message=None)

  Bases: `PyQt4.QtGui.QListView`, `umbra.ui.views.Mixin_AbstractView`

  This class is a QListView subclass used as base by others Application Views classes.

  Parameters: | parent – Object parent. ( QObject ) readOnly – View is read only. ( Boolean ) message – View default message when Model is empty. ( String )

class `umbra.ui.views.` `Abstract_QTableView`(parent=None, readOnly=False, message=None)

  Bases: `PyQt4.QtGui.QTableView`, `umbra.ui.views.Mixin_AbstractView`

  This class is a QTableView subclass used as base by others Application Views classes.

  Parameters: | parent – Object parent. ( QObject ) readOnly – View is read only. ( Boolean ) message – View default message when Model is empty. ( String )

class `umbra.ui.views.` `Abstract_QTreeView`(parent=None, readOnly=False, message=None)

  Bases: `PyQt4.QtGui.QTreeView`, `umbra.ui.views.Mixin_AbstractView`

  This class is a QTreeView subclass used as base by others Application Views classes.

  Parameters: | parent – Object parent. ( QObject ) readOnly – View is read only. ( Boolean ) message – View default message when Model is empty. ( String )

class `umbra.ui.views.` `Abstract_QListWidget`(parent=None, message=None)

  Bases: `PyQt4.QtGui.QListWidget`, `umbra.ui.views.Mixin_AbstractWidget`

  This class is a QListWidget subclass used as base by others Application Widgets Views classes.

  Parameters: | parent – Object parent. ( QObject ) message – View default message when Model is empty. ( String )

class `umbra.ui.views.` `Abstract_QTableWidget`(parent=None, readOnly=False, message=None)

  Bases: `PyQt4.QtGui.QTableWidget`, `umbra.ui.views.Mixin_AbstractWidget`

  This class is a QTableWidget subclass used as base by others Application Widgets Views classes.

  Parameters: | parent – Object parent. ( QObject ) message – View default message when Model is empty. ( String )

class `umbra.ui.views.` `Abstract_QTreeWidget`(parent=None, message=None)

  Bases: `PyQt4.QtGui.QTreeWidget`, `umbra.ui.views.Mixin_AbstractWidget`

  This class is a QTreeWidget subclass used as base by others Application Widgets Views classes.

  Parameters: | parent – Object parent. ( QObject ) message – View default message when Model is empty. ( String )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »